@@ -1,5 +1,5 @@
 # -!- coding: utf-8 -!-
-import re, os, requests, time, random
+import re, os, requests, time, random, chardet
 from html.parser import HTMLParser
 from random import randint
 from scrapy import Selector
@@ -141,21 +141,17 @@ class req_base():
     def html_get_title(self, html):
         return Selector(text=html).xpath('//title/text()').extract()[0]
 
+    def r_get_encoding(self, r): return chardet.detect(r.content)['encoding']
+
     def r_get_html(self, r):
-        try: html = r.text
-        except Exception as err: html = err
-        codes = ('utf8', 'gbk', r.encoding)
-        for x in codes:
-            try: return r.content.decode(x)
+        content = r.content
+        # 优先展示中文
+        for x in ('utf8', 'gbk', r.encoding):
+            try: return content.decode(x)
             except: pass
-        for x in codes:
-            try:
-                rc = deepcopy(r)
-                rc.encoding = x
-                return rc.text
-            except: pass
-        if type(html) is str: return html
-        raise html
+        # 无法展示中文时, 才展示非中文
+        try: return r.text
+        except: return content.decode(self.r_get_encoding(r))
 
     def url_get_是否内页(self, url):
         r = re.findall('/.+', re.sub('^https?://| ', '', url))
