@@ -366,6 +366,8 @@ class 供应链api():
                 raise Exception('修改套餐 方法需要增加对 品牌单项 和 机构单项 的支持')
             else:
                 单项s = [dict(itemId=x['单项id'], source=x['source']) for x in 详情['单项']['系统单项s']]
+        性别婚否 = kvs.get('性别和婚否', 套餐['性别和婚否'])
+        性别婚否 = 性别和婚否字典.get(性别婚否, 性别婚否)
         newdata = dict(
             packageId = 套餐id,
             attributes = [dict(dictDataKey=s['标签key'], dictDataValue=s['标签名称'], dictTypeId=s['类型id']) for s in kvs.get('标签s', 详情['标签'])],
@@ -375,7 +377,7 @@ class 供应链api():
             packageName = kvs.get('套餐名称', 详情['供应链套餐']['套餐名称']),
             packageAlias = kvs.get('套餐名称', 套餐['套餐别名'] or 套餐['套餐名称']),
             packageDiscount = kvs.get('折扣', 套餐['套餐折扣']),
-            packageGender = 性别和婚否字典[kvs.get('性别和婚否', 套餐['性别和婚否'])],
+            packageGender = 性别婚否,
             packageOriginalPrice = kvs.get('原价', 套餐['套餐原价']),
             packageSellingPrice = kvs.get('售价', 套餐['套餐售价']),
             packagePresettlePrice = kvs.get('预估结算价', 套餐['套餐预估结算价']),
